@@ -55,6 +55,7 @@ static gboolean     gtk2hs_store_get_sort_column_id     (GtkTreeSortable
 static void         gtk2hs_store_set_sort_column_id     (GtkTreeSortable        *sortable,
                                                          gint                   sort_column_id,
                                                          GtkSortType            order);
+#if GTK_MAJOR_VERSION < 3
 static void	    gtk2hs_store_set_sort_func		(GtkTreeSortable        *sortable,
                                                          gint                   sort_column_id,
                                                          GtkTreeIterCompareFunc func,
@@ -64,6 +65,7 @@ static void         gtk2hs_store_set_default_sort_func  (GtkTreeSortable
                                                          GtkTreeIterCompareFunc func,
                                                          gpointer               data,
                                                          GtkDestroyNotify       destroy);
+#endif
 static gboolean     gtk2hs_store_has_default_sort_func  (GtkTreeSortable        *sortable);
 
 
@@ -120,6 +122,7 @@ gtk2hs_store_get_type (void)
       NULL
     };
 
+#if GTK_MAJOR_VERSION < 3
 /* The TreeSortable interface is currently not implemented. */
     static const GInterfaceInfo tree_sortable_info =
     {
@@ -127,7 +130,7 @@ gtk2hs_store_get_type (void)
       NULL,
       NULL
     };
-
+#endif
     static const GInterfaceInfo tree_drag_source_info =
     {
       (GInterfaceInitFunc) gtk2hs_store_tree_drag_source_init,
@@ -215,6 +218,7 @@ gtk2hs_store_tree_model_init (GtkTreeModelIface *iface)
   iface->unref_node      = gtk2hs_store_unref_node;
 }
 
+#if GTK_MAJOR_VERSION < 3
 /**
  *
  *  gtk2hs_store_tree_sortable_init: init callback for the interface registration
@@ -234,7 +238,7 @@ gtk2hs_store_tree_sortable_init (GtkTreeSortableIface *iface)
   iface->set_default_sort_func  = gtk2hs_store_set_default_sort_func;
   iface->has_default_sort_func  = gtk2hs_store_has_default_sort_func;
 }
-
+#endif
 /**
  *
  *  gtk2hs_store_tree_drag_source_init: init callback for the interface registration
@@ -270,7 +274,7 @@ gtk2hs_store_tree_drag_dest_init (GtkTreeDragDestIface *iface)
 
 /**
  *
- *  gtk2hs_store_init: this is called everytime a new custom list object
+ *  gtk2hs_store_init: this is called every time a new custom list object
  *                     instance is created (we do that in gtk2hs_store_new).
  *                     Initialise the list structure's fields here.
  *
@@ -458,7 +462,6 @@ gtk2hs_store_iter_next (GtkTreeModel  *tree_model,
   WHEN_DEBUG(g_debug("calling gtk2hs_store_iter_next\t\t(%p, %p)\n", tree_model, iter));
   Gtk2HsStore *store = (Gtk2HsStore *) tree_model;
   g_return_val_if_fail (GTK2HS_IS_STORE (tree_model), FALSE);
-  g_return_val_if_fail (iter->stamp == store->stamp, FALSE);
 
   gboolean result = gtk2hs_store_iter_next_impl(store->impl, iter);
   if (result) iter->stamp = store->stamp;
@@ -485,7 +488,6 @@ gtk2hs_store_iter_children (GtkTreeModel *tree_model,
   WHEN_DEBUG(g_debug("calling gtk2hs_store_iter_children\t(%p, %p, %p)\n", tree_model, iter, parent));
   Gtk2HsStore *store = (Gtk2HsStore *) tree_model;
   g_return_val_if_fail (GTK2HS_IS_STORE (tree_model), FALSE);
-  g_return_val_if_fail (parent == NULL || parent->stamp == store->stamp, FALSE);
 
   gboolean result = gtk2hs_store_iter_children_impl(store->impl, iter, parent);
   if (result) iter->stamp = store->stamp;
@@ -507,7 +509,8 @@ gtk2hs_store_iter_has_child (GtkTreeModel *tree_model,
   WHEN_DEBUG(g_debug("calling gtk2hs_store_iter_has_child\t(%p, %p)\n", tree_model, iter));
   Gtk2HsStore *store = (Gtk2HsStore *) tree_model;
   g_return_val_if_fail (GTK2HS_IS_STORE (tree_model), FALSE);
-  g_return_val_if_fail (iter->stamp == store->stamp, FALSE);
+  /* don't check if iter->stamp == store->stamp; see the thread culminating in
+   * http://sourceforge.net/p/gtk2hs/mailman/message/31887332/ for details */
   
   gboolean result = gtk2hs_store_iter_has_child_impl(store->impl, iter);
   WHEN_DEBUG(g_debug("return  gtk2hs_store_iter_has_child\t=%s\n", result ? "TRUE" : "FALSE"));
@@ -599,7 +602,6 @@ gtk2hs_store_ref_node (GtkTreeModel *tree_model,
   WHEN_DEBUG(g_debug("calling gtk2hs_store_ref_node\t\t(%p, %p)\n", tree_model, iter));
   Gtk2HsStore *store = (Gtk2HsStore *) tree_model;
   g_return_if_fail (GTK2HS_IS_STORE (tree_model));
-  g_return_if_fail (iter->stamp == store->stamp);
 
   gtk2hs_store_ref_node_impl(store->impl, iter);
 }
@@ -634,6 +636,7 @@ gtk2hs_store_set_sort_column_id (GtkTreeSortable        *sortable,
   return;
 }
 
+#if GTK_MAJOR_VERSION < 3
 static void
 gtk2hs_store_set_sort_func (GtkTreeSortable        *sortable,
                             gint                   sort_column_id,
@@ -654,7 +657,7 @@ gtk2hs_store_set_default_sort_func (GtkTreeSortable        *sortable,
   WHEN_DEBUG(g_debug("calling gtk2hs_store_set_default_sort_func\t\t(%p)\n", sortable));
   return;
 }
-
+#endif
 static gboolean
 gtk2hs_store_has_default_sort_func (GtkTreeSortable        *sortable)
 {
