@@ -1,7 +1,6 @@
 module Main (main) where
 
 import Graphics.UI.Gtk
-import Control.Monad.IO.Class (liftIO)
 
 main :: IO ()
 main = do
@@ -29,8 +28,8 @@ main = do
                  | button <- [button1, button2, button3] ]
 
   -- This sets button3 to be a so called 'secondary child'. When the layout
-  -- stlye is ButtonboxStart or ButtonboxEnd, the secondary children are
-  -- grouped seperately from the others. Resize the window to see the effect.
+  -- style is ButtonboxStart or ButtonboxEnd, the secondary children are
+  -- grouped separately from the others. Resize the window to see the effect.
   --
   -- This is not interesting in itself but shows how to set child attributes.
   -- Note that the child attribute 'buttonBoxChildSecondary' takes the
