@@ -1,5 +1,5 @@
 #include <gtk/gtk.h>
-/* these are necessary on Win32 to circumvent the strcuture size check */
+/* these are necessary on Win32 to circumvent the structure size check */
 #undef gtk_init_check
 #undef gtk_init
 
@@ -70,3 +70,15 @@
 #undef ColormapChangeMask
 #undef OwnerGrabButtonMask
 
+#undef Status
+#undef Expose
+#undef Below
+#undef GrabSuccess
+#undef GrabAlreadyGrabbed
+#undef GrabInvalidTime
+#undef GrabNotViewable
+#undef GrabFrozen
+#undef OwnerChangeNewOwner
+#undef OwnerChangeDestroy
+#undef OwnerChangeClose
+#undef NULL
